Index: ui/views/corewm/tooltip_controller.h |
diff --git a/ui/views/corewm/tooltip_controller.h b/ui/views/corewm/tooltip_controller.h |
index 9815df1817a46d4f76cf17c459310b0502a34ead..e0453341f0059583086245e026edf0fde84ac8d8 100644 |
--- a/ui/views/corewm/tooltip_controller.h |
+++ b/ui/views/corewm/tooltip_controller.h |
@@ -61,7 +61,7 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient, |
void TooltipShownTimerFired(); |
// Updates the tooltip if required (if there is any change in the tooltip |
// text or the aura::Window. |
void UpdateIfRequired(); |
// Only used in tests. |
@@ -81,6 +81,7 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient, |
aura::Window* tooltip_window_; |
base::string16 tooltip_text_; |
+ const void* tooltip_id_; |
// These fields are for tracking state when the user presses a mouse button. |
aura::Window* tooltip_window_at_mouse_press_; |
@@ -61,7 +61,7 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient, |
void TooltipShownTimerFired(); |
// Updates the tooltip if required (if there is any change in the tooltip |
- // text or the aura::Window. |
+ // text, tooltip id or the aura::Window). |
void UpdateIfRequired(); |
// Only used in tests. |